"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = require("path");
const unist_util_visit_1 = __importDefault(require("unist-util-visit"));
const path_2 = __importDefault(require("path"));
function rehypeDocs({ filePath }) {
    function visitInlineCode(node) {
        const value = node.value;
        if (value.startsWith('markdown:')) {
            const file = value.substr(9);
            const combinedPath = path_2.default.normalize(path_1.dirname(filePath) + '/' + file);
            if (!fs_1.default.existsSync(combinedPath)) {
                throw Error(`Invalid fragment specified; no such file "${combinedPath}"`);
            }
            const code = fs_1.default.readFileSync(combinedPath, 'utf8');
            try {
                node.value = code;
                node.type = 'markdown';
            }
            catch (e) {
                throw Error(`${e.message} \nFile: ${file}`);
            }
        }
    }
    function visitLink(node) {
        if (node.children.length > 0 && node.children[0].value === '!embed') {
            const file = node.url;
            const path = path_1.dirname(filePath) + '/' + file;
            if (!fs_1.default.existsSync(path)) {
                throw Error(`Invalid fragment specified; no such file "${path}"`);
            }
            const code = fs_1.default.readFileSync(path, 'utf8');
            try {
                node.value = code;
                node.type = 'markdown';
            }
            catch (e) {
                throw Error(`${e.message} \nFile: ${file}`);
            }
        }
        if (node.children.length > 0 && node.children[0].value.indexOf('%') === 0) {
            node.value = `[Video: ${node.children[0].value.substring(1)}](${node.url})`;
            node.type = 'markdown';
        }
    }
    return function transformer(tree) {
        unist_util_visit_1.default(tree, 'inlineCode', visitInlineCode);
        unist_util_visit_1.default(tree, (node) => node.type === 'link', visitLink);
        return tree;
    };
}
exports.default = rehypeDocs;
//# sourceMappingURL=rehypeMarkdownToMarkdown.js.map